@@ -4,12 +4,12 @@ import errno
 import logging
 import logging.handlers
 from optparse import OptionParser
-import archiver
+import pyppd.archiver
 
 def parse_args():
     usage = "usage: %prog [options] ppds_directory"
-    version = "%prog 0.4.9\n" \
-              "Copyright (c) 2010 Vitor Baptista.\n" \
+    version = "%prog 1.0.0\n" \
+              "Copyright (c) 2012 Vitor Baptista.\n" \
               "This is free software; see the source for copying conditions.\n" \
               "There is NO warranty; not even for MERCHANTABILITY or\n" \
               "FITNESS FOR A PARTICULAR PURPOSE."
@@ -60,12 +60,12 @@ def run():
     ppds_directory = args[0]
 
     logging.info('Archiving folder "%s".' % ppds_directory)
-    archive = archiver.archive(ppds_directory)
+    archive = pyppd.archiver.archive(ppds_directory)
     if not archive:
         exit(errno.ENOENT)
 
     logging.info('Writing archive to "%s".' % options.output)
-    output = open(options.output, "w+")
+    output = open(options.output, "wb+")
     output.write(archive)
     output.close()
 
